@@ -74,7 +74,7 @@ def compute_df_mismatches_wide(df_mismatches):
 
             df_mismatches_wide.append(
                 df_mismatches.query(d_direction[direction]["query"])
-                .pivot(index="tax_id", columns="|z|", values=variable)
+                .pivot(index="tax_id", columns="|x|", values=variable)
                 .rename(columns=columns)
             )
 
@@ -122,7 +122,8 @@ def merge(
 
 
 def get_database_read_ids(config):
-    read_ids_mapping = read_filename_lca(config["path_lca"])
+    file_lca = config["path_lca"]
+    read_ids_mapping = read_filename_lca(file_lca)
     return read_ids_mapping
 
     # db = database(filename_database)
